@@ -327,9 +327,10 @@ bool SendImages::showErrors()
 
 void SendImages::invokeMailAgent(void)
 {
-    // Kmail agent call.
+    // default agent call
+    // FIXME: seems to fail for thunderbird. Fix kdelibs or maybe work around it.
 
-    if ( m_sendImagesDialog->m_mailAgentName->currentText() == "Kmail" )
+    if ( m_sendImagesDialog->m_mailAgentName->currentText() == "Default" )
        {
        KApplication::kApplication()->invokeMailer(
                        QString::null,                     // Destination address.
@@ -342,6 +343,25 @@ void SendImages::invokeMailAgent(void)
        }
 
 
+    // KMail mail agent call.
+
+    if ( m_sendImagesDialog->m_mailAgentName->currentText() == "KMail" )
+    {
+        m_mailAgentProc = new KProcess;
+        *m_mailAgentProc << "kmail";
+
+        for ( KURL::List::Iterator it = m_filesSendList.begin() ; it != m_filesSendList.end() ; ++it )
+        {
+            *m_mailAgentProc << "--attach";
+            *m_mailAgentProc << QFile::encodeName((*it).path());
+        }
+
+        if ( m_mailAgentProc->start() == false )
+            KMessageBox::error(kapp->activeWindow(), i18n("Cannot start '%1' program;\nplease "
+                                                          "check your installation.")
+                               .arg(m_sendImagesDialog->m_mailAgentName->currentText()));
+    }
+
     // Sylpheed mail agent call.
 
     if ( m_sendImagesDialog->m_mailAgentName->currentText() == "Sylpheed" ||
